%This script allows to transform Z maps from Activation Likelihood
%Estimation analysis into minimum Bayes Factor maps.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%fin= a Z map obtained through a p-to-Z conversion from a p-value map, as it is produced  at the end of any Activation
%     Likelihood Estimation computation. If using GingerALE a Z map is
%     directly produced.

%fout= a .nii file where the voxel values express the Bayes Factor. Note
%      that the output is unthresholded, therefore the minimum Bayes Factor
%      threshold can be then placed depending on users' needs.

%Please note that the toolbox 'Tools for NIfTI and ANALYZE image' 
%(https://www.mathworks.com/matlabcentral/fileexchange/8797-tools-for-nifti-and-analyze-image) must be in the path. 

%Example: p=minimumBF('Z_test.nii','mBF_test.nii')

%Coded by Tommaso Costa (FocusLab, University of Torino) in November 2021.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function p=minimumBF(fin,fout)

%Load the Z map and set negative values to 0.
    nii=load_nii(fin);
    img=nii.img;
    i=find(img(:)<0);
    img(i)=0;
    
%Transform values through exponentiation
    img=exp(-(img(:).^2)/2);
    img=1./img;
    
%Set possible infinite values to 10^80.
    k=find(isinf(img));
    img=double(img);
    img(k)=10^80;
    
%Set possible NaN values to 0.
    k=find(isnan(img));
    img(k)=0;

%Save the output .nii map.
    nii.img(:)=0;
    nii.img=img;
    % nii.hdr.dime.datatype=64; %Uncomment this to save a 64bit .nii
    save_nii(nii,fout);
    p=1;
    
    disp('Done! Thank you for using this tool! :-D')
return

